@@ -271,6 +271,15 @@ sub dump {
 	# Repeat the above match on remaining description
 	($left, $special, $right) = ($remainder =~ $match_description);
 
+    # Check for "K<season>, J<episode: <sub-title>...."
+    } elsif (($desc_season, $desc_episode, $remainder) =
+	     ($description =~ m/^K(\d+),\s+J(\d+):\s+(.*)$/)) {
+	$season  = $desc_season;
+	$episode = $desc_episode;
+
+	# Repeat the above match on remaining description
+	($left, $special, $right) = ($remainder =~ $match_description);
+
     # Check for "<sub-title>. Kausi <season>, (jakso )?<episode>/<# of episodes>...."
     } elsif (($desc_subtitle, $desc_season, $desc_episode, $desc_total, $remainder) =
 	     ($description =~ m!^(.+)\s+Kausi\s+(\d+),\s+(?:jakso\s+)?(\d+)(?:/(\d+))?\.\s*(.*)$!)) {
